/*
 * Copyright 2011 DeepDiff Contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package deepdiff.app;

import static org.hamcrest.CoreMatchers.equalTo;
import static org.hamcrest.CoreMatchers.instanceOf;
import static org.hamcrest.CoreMatchers.sameInstance;
import static org.junit.Assert.assertThat;

import java.util.Arrays;

import org.junit.After;
import org.junit.Test;
import org.xml.sax.InputSource;

import com.google.common.collect.Lists;

import deepdiff.core.DiffPointProcessor;
import deepdiff.core.DiffPointProcessorFactory;
import deepdiff.core.DiffUnitProcessor;
import deepdiff.core.DiffUnitProcessorFactory;
import deepdiff.pointprocessor.OutputDiffPointProcessor;
import deepdiff.pointprocessor.RegexFilterDiffPointProcessor;
import deepdiff.unitprocessor.BinaryCompareDiffUnitProcessor;
import deepdiff.unitprocessor.DelegatingDiffUnitProcessor;
import deepdiff.unitprocessor.ManifestCompareDiffUnitProcessor;
import deepdiff.unitprocessor.PropertiesCompareDiffUnitProcessor;
import deepdiff.unitprocessor.SortedZipCompareDiffUnitProcessor;
import deepdiff.unitprocessor.XMLCompareDiffUnitProcessor;

public class DeepDiffTest {
    @After
    public void tearDown() {
        DiffUnitProcessorFactory.clear();
        DiffPointProcessorFactory.clear();
    }

    @Test
    public void testDefaultConfig() throws Exception {
        DeepDiff app = new DeepDiff();
        InputSource source = new InputSource(app.getDefaultConfigStream());
        app.loadConfig(source);

        DiffUnitProcessor manifestUnitProcessor = DiffUnitProcessorFactory.get("manifest");
        DiffUnitProcessor propertiesUnitProcessor = DiffUnitProcessorFactory.get("properties");
        DiffUnitProcessor zipUnitProcessor = DiffUnitProcessorFactory.get("zip");
        DiffUnitProcessor xmlUnitProcessor = DiffUnitProcessorFactory.get("xml");
        DiffUnitProcessor binaryUnitProcessor = DiffUnitProcessorFactory.get("binary");
        DiffUnitProcessor defaultUnitProcessor = DiffUnitProcessorFactory.getDefault();
        assertThat(manifestUnitProcessor, instanceOf(ManifestCompareDiffUnitProcessor.class));
        assertThat(propertiesUnitProcessor, instanceOf(PropertiesCompareDiffUnitProcessor.class));
        assertThat(zipUnitProcessor, instanceOf(SortedZipCompareDiffUnitProcessor.class));
        assertThat(xmlUnitProcessor, instanceOf(XMLCompareDiffUnitProcessor.class));
        assertThat(binaryUnitProcessor, instanceOf(BinaryCompareDiffUnitProcessor.class));
        assertThat(defaultUnitProcessor, instanceOf(DelegatingDiffUnitProcessor.class));
        DelegatingDiffUnitProcessor delegatingUnitProcessor = (DelegatingDiffUnitProcessor) defaultUnitProcessor;
        assertThat(Lists.newArrayList(delegatingUnitProcessor.getHandlers().keySet()),
                equalTo(Arrays.asList(".*[/\\\\!]META-INF[/\\\\]MANIFEST\\.MF", ".*\\.properties",
                        ".*\\.zip", ".*\\.jar", ".*\\.war", ".*\\.ear", ".*")));
        assertThat(Lists.newArrayList(delegatingUnitProcessor.getHandlers().values()),
                equalTo(Arrays.asList(manifestUnitProcessor, propertiesUnitProcessor,
                        zipUnitProcessor, zipUnitProcessor, zipUnitProcessor, zipUnitProcessor,
                        binaryUnitProcessor)));

        DiffPointProcessor outPointProcessor = DiffPointProcessorFactory.get("out");
        DiffPointProcessor defaultPointProcessor = DiffPointProcessorFactory.getDefault();
        assertThat(outPointProcessor, instanceOf(OutputDiffPointProcessor.class));
        assertThat(defaultPointProcessor, instanceOf(RegexFilterDiffPointProcessor.class));
        RegexFilterDiffPointProcessor regexPointProcessor = (RegexFilterDiffPointProcessor) defaultPointProcessor;
        assertThat(regexPointProcessor.getChild(), sameInstance(outPointProcessor));
    }
}
