/*
 * Copyright 2011 DeepDiff Contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package deepdiff.core;

import static org.hamcrest.CoreMatchers.equalTo;
import static org.hamcrest.CoreMatchers.instanceOf;
import static org.junit.Assert.assertThat;

import java.io.File;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import com.google.common.io.Files;

import deepdiff.scope.FileDiffScope;
import deepdiff.test.TestLogAppender;
import deepdiff.unitprocessor.DelegatingDiffUnitProcessor;

public class DiffUnitProcessorFactoryTest {
    private TestLogAppender testLog;

    @Before
    public void setUp() {
        DiffUnitProcessor defaultProcessor = new DelegatingDiffUnitProcessor();
        DiffUnitProcessorFactory.set(DiffUnitProcessorFactory.DEFAULT_ID, defaultProcessor);

        testLog = new TestLogAppender();
        testLog.install();
    }

    @After
    public void tearDown() {
        DiffUnitProcessorFactory.clear();
        testLog.uninstall();
    }

    @Test
    public void testCreateInitialScopeTwoDirectories() throws Exception {
        File leftFile = Files.createTempDir();
        try {
            File rightFile = Files.createTempDir();
            try {
                DiffScope scope = DiffUnitProcessorFactory.createInitialScope(leftFile, rightFile);
                assertThat(scope, instanceOf(FileDiffScope.class));
                assertThat(testLog.getEvents().size(), equalTo(0));
            } finally {
                rightFile.delete();
            }
        } finally {
            leftFile.delete();
        }
    }

    @Test
    public void testCreateInitialScopeTwoTextFiles() throws Exception {
        String prefix = getClass().getName();
        File leftFile = File.createTempFile(prefix, ".txt");
        try {
            File rightFile = File.createTempFile(prefix, ".txt");
            try {
                DiffScope scope = DiffUnitProcessorFactory.createInitialScope(leftFile, rightFile);
                assertThat(scope, instanceOf(FileDiffScope.class));
                assertThat(testLog.getEvents().size(), equalTo(0));
            } finally {
                rightFile.delete();
            }
        } finally {
            leftFile.delete();
        }
    }
}
